MODULE trcini_my_trc
   !!======================================================================
   !!                         ***  MODULE trcini_my_trc  ***
   !! TOP :   initialisation of the MY_TRC tracers
   !!======================================================================
   !! History :   2.0  !  2007-12  (C. Ethe, G. Madec) Original code
   !!----------------------------------------------------------------------
#if defined key_my_trc
   !!----------------------------------------------------------------------
   !!   'key_my_trc'                                               CFC tracers
   !!----------------------------------------------------------------------
   !! trc_ini_my_trc   : MY_TRC model initialisation
   !!----------------------------------------------------------------------
   USE par_trc         ! TOP parameters
   USE oce_trc
   USE trc
   USE trcsms_my_trc
   USE trcnam_my_trc , ONLY : rHDOref,rO18ref,SELref  ! ref isotopic ratio and salinity

   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_ini_my_trc   ! called by trcini.F90 module

   !!----------------------------------------------------------------------
   !! NEMO/TOP 3.3 , NEMO Consortium (2010)
   !! $Id: trcini_my_trc.F90 2787 2011-06-27 09:54:00Z cetlod $ 
   !! Software governed by the CeCILL licence     (NEMOGCM/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------
CONTAINS

   SUBROUTINE trc_ini_my_trc
      !!----------------------------------------------------------------------
      !!                     ***  trc_ini_my_trc  ***  
      !!
      !! ** Purpose :   initialization for MY_TRC model
      !!
      !! ** Method  : 
      !!----------------------------------------------------------------------
      !
      REAL(wp) :: ztrai  !,zutmin,zutmax 
      INTEGER  :: ji,jj,jk,jn,jq
      !                       ! Allocate MY_TRC arrays
      IF( trc_sms_my_trc_alloc() /= 0 )   CALL ctl_stop( 'STOP', 'trc_ini_my_trc: unable to allocate MY_TRC arrays' )

      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) ' trc_ini_my_trc: initialisation of MY_TRC model'
      !
      IF( .NOT. ln_rsttr )  THEN
      !
        IF(lwp) WRITE(numout,*) '                      ==>    HOMOGENEOUS VALUES'
      !
        ztrai=0.05
        jq=jpk/4
        !IF(lwp) write(numout,*) jpj,jpi,jq,jpk
        trn(:,:,:,jpmyt1) = SELref * tmask(:,:,:)
        DO jj = 1, jpj
         ztrai=-1.*ztrai
         DO ji = 1,jpi
          DO jk = 1,jq
           trn(ji,jj,jk,jpmyt2) = (SELref+ztrai) * tmask(ji,jj,jk)
           trn(ji,jj,jk,jpmyt3) = trn(ji,jj,jk,jpmyt1)
           trn(ji,jj,jk,jpmyt4)= trn(ji,jj,jk,jpmyt2)
          END DO
          DO jk = jq+1,jpk
           trn(ji,jj,jk,jpmyt2) = trn(ji,jj,jk,jpmyt1)
           trn(ji,jj,jk,jpmyt3) = (SELref+ztrai) * tmask(ji,jj,jk)
           trn(ji,jj,jk,jpmyt4)= trn(ji,jj,jk,jpmyt3)
          END DO
         END DO
        END DO
        trn(:,:,:,jpmyt5) = trn(:,:,:,jpmyt1)
        trn(:,:,:,jpmyt6) = trn(:,:,:,jpmyt1)
      !
      ! >>>>> Sais pas pourquoi mais SI ceci ET PAS le write avant DO jj : il se plante grave !!!???
      !  zutmin  = MINVAL( trn(:,:,:,jpmyt4), mask= ((tmask*SPREAD(tmask_i,DIM=3,NCOPIES=jpk).NE.0.)) )
      !  zutmax  = MAXVAL( trn(:,:,:,jpmyt4), mask= ((tmask*SPREAD(tmask_i,DIM=3,NCOPIES=jpk).NE.0.)) )

      !
      END IF
      !
      ztrai = 0._wp                                                   !  content of all tracers
      DO jn = 1, jptra
         ztrai = ztrai + glob_sum( trn(:,:,:,jn) * cvol(:,:,:)   )
      END DO
      IF( lwp ) WRITE(numout,'(a,e18.10)') 'Initial mean content:',  ztrai / areatot
      !IF( lwp ) WRITE(numout,'(a,2e18.10)') 'Initial min max for jpmyt4:',  zutmin,zutmax
      !
      IF(lwp) WRITE(numout,*) ' ~~~~~~~~~~~~~~'
      !
   END SUBROUTINE trc_ini_my_trc

#else
   !!----------------------------------------------------------------------
   !!   Dummy module                                        No MY_TRC model
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_ini_my_trc             ! Empty routine
   END SUBROUTINE trc_ini_my_trc
#endif

   !!======================================================================
END MODULE trcini_my_trc
