MODULE trcnam_my_trc
   !!======================================================================
   !!                      ***  MODULE trcnam_my_trc  ***
   !! TOP :   initialisation of some run parameters for WATISTOP model
   !!======================================================================
   !! History :   2.0  !  2007-12  (C. Ethe, G. Madec) Original code
   !!----------------------------------------------------------------------
#if defined key_my_trc
   !!----------------------------------------------------------------------
   !!   'key_my_trc'   :                                       MY_TRC model
   !!----------------------------------------------------------------------
   !! trc_nam_my_trc      : MY_TRC model initialisation
   !!----------------------------------------------------------------------
   USE oce_trc         ! Ocean variables
   USE par_trc         ! TOP parameters
   USE trc             ! TOP variables

   IMPLICIT NONE
   PRIVATE
   INTEGER , PUBLIC :: numnatw
   CHARACTER (len=20), PUBLIC, DIMENSION(4)   :: cwatdia ! CECI SERA A AMELIORER <====!!
   LOGICAL, SAVE, PUBLIC :: ln_watdia,ln_force_mass
   REAL(wp), SAVE, PUBLIC :: rHDOref,rO17ref,rO18ref,SELref
   !!

   PUBLIC   trc_nam_my_trc   ! called by trcnam.F90 module

   !!----------------------------------------------------------------------
   !! NEMO/TOP 3.3 , NEMO Consortium (2010)
   !! $Id: trcnam_my_trc.F90 2528 2010-12-27 17:33:53Z rblod $ 
   !! Software governed by the CeCILL licence (NEMOGCM/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_nam_my_trc
      !!----------------------------------------------------------------------
      !!                     ***  trc_nam_my_trc  ***  
      !!
      !! ** Purpose :   read MY_TRC namelist
      !!
      !!----------------------------------------------------------------------
      !
      !!
      NAMELIST/namwat_ref/ rHDOref,rO17ref,rO18ref,SELref  ! isotopic ref ratio
      NAMELIST/namwat_dia/ ln_watdia,cwatdia     ! additional diagnostics short names
      NAMELIST/namwat_mass/ ln_force_mass !  mass conservation 
      !!  NAMELIST/namwat_flx/    ! atmospheric fluxes <=== read in trcflx_watistop
      !!-------------------------------------------------------------------

      ! default namelist value
      ln_watdia=.false.
      cwatdia(1)='dO18'
      cwatdia(2)='dHDO'
      cwatdia(3)='DO18'
      cwatdia(4)='DHDO'
      rHDOref = 155.76D-06    !!  (2H/1H) VSMOW
      rO17ref = 379.9D-06     !!  (17O/16O) VSMOW
      rO18ref = 2005.2D-06    !!  (18O/16O) VSMOW
      SELref = 34.7           !!  Global mean salinity
      ln_force_mass = .false. !!  Force mass conservation


      !                             ! Open namelist file
      CALL ctl_opn( numnatw, 'namelist_watistop', 'OLD', 'FORMATTED', 'SEQUENTIAL', -1, numout, .FALSE. )

      READ (  numnatw,namwat_ref )     ! read namelist
      READ (  numnatw,namwat_dia )     ! read namelist
      READ (  numnatw,namwat_mass )     ! read namelist


      IF(lwp) THEN
       WRITE(numout,*)
       WRITE(numout,*) ' trc_nam_my_trc : read MY_TRC namelists'
       IF(ln_force_mass) WRITE(numout,*) 'Mass forced'
       WRITE(numout,*) SELref,rHDOref,rO18ref,rO17ref
       IF(ln_watdia) WRITE(numout,*) 'Additional diagnostics: ',cwatdia
       WRITE(numout,*) ' ~~~~~~~~~~~~~~~'
      ENDIF
      !
   END SUBROUTINE trc_nam_my_trc
   
#else
   !!----------------------------------------------------------------------
   !!  Dummy module :                                             No MY_TRC
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_nam_my_trc                      ! Empty routine
   END  SUBROUTINE  trc_nam_my_trc
#endif  

   !!======================================================================
END MODULE trcnam_my_trc
